==> maru-0.0.1-all.zip: org/maru/dog/core/ObjectFactory.java <==
/*
 * Copyright 2011 maru project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maru.dog.core;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

import org.maru.core.reflection.Clazz;
import org.maru.core.util.ConditionUtil;

/**
 * Object factory class.
 *
 */
public class ObjectFactory {

    private ObjectFactory() {
        throw new RuntimeException();
    }

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(Class<T> type) {
        Constructor<?> constructor = Clazz.getDefaultConstructor(type);

        ConditionUtil.verifyNotNull(constructor,
                "There is no default constructor to instantiate object.");

        try {
            return (T) constructor.newInstance(null);
        } catch (IllegalArgumentException e) {
            throw new RuntimeException(e);
        } catch (InstantiationException e) {
            throw new RuntimeException(e);
        } catch (IllegalAccessException e) {
            throw new RuntimeException(e);
        } catch (InvocationTargetException e) {
            throw new RuntimeException(e);
        }
    }
}

==> maru-0.6.17-all.zip: org/maru/dog/core/ObjectFactory.java <==
/*
 * Copyright 2011 maru project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maru.dog.core;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

import org.maru.common.reflection.Clazz;
import org.maru.common.util.ConditionUtil;

/**
 * Object factory class.
 *
 */
public class ObjectFactory {

    private ObjectFactory() {
        throw new RuntimeException();
    }

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(Class<T> type) {
        Constructor<?> constructor = Clazz.getDefaultConstructor(type);

        ConditionUtil.verifyNotNull(constructor,
                "There is no default constructor to instantiate object.");

        try {
            return (T) constructor.newInstance(null);
        } catch (IllegalArgumentException e) {
            throw new RuntimeException(e);
        } catch (InstantiationException e) {
            throw new RuntimeException(e);
        } catch (IllegalAccessException e) {
            throw new RuntimeException(e);
        } catch (InvocationTargetException e) {
            throw new RuntimeException(e);
        }
    }
}
